==> openshift-model-operator-6.9.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/PerspectiveVisibilityFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PerspectiveVisibilityFluent<A extends PerspectiveVisibilityFluent<A>> extends BaseFluent<A>{
  public PerspectiveVisibilityFluent() {
  }
  
  public PerspectiveVisibilityFluent(PerspectiveVisibility instance) {
    this.copyInstance(instance);
  }
  private ResourceAttributesAccessReviewBuilder accessReview;
  private String state;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PerspectiveVisibility instance) {
    instance = (instance != null ? instance : new PerspectiveVisibility());
    if (instance != null) {
          this.withAccessReview(instance.getAccessReview());
          this.withState(instance.getState());
          this.withAccessReview(instance.getAccessReview());
          this.withState(instance.getState());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ResourceAttributesAccessReview buildAccessReview() {
    return this.accessReview != null ? this.accessReview.build() : null;
  }
  
  public A withAccessReview(ResourceAttributesAccessReview accessReview) {
    this._visitables.remove(this.accessReview);
    if (accessReview != null) {
        this.accessReview = new ResourceAttributesAccessReviewBuilder(accessReview);
        this._visitables.get("accessReview").add(this.accessReview);
    } else {
        this.accessReview = null;
        this._visitables.get("accessReview").remove(this.accessReview);
    }
    return (A) this;
  }
  
  public boolean hasAccessReview() {
    return this.accessReview != null;
  }
  
  public AccessReviewNested<A> withNewAccessReview() {
    return new AccessReviewNested(null);
  }
  
  public AccessReviewNested<A> withNewAccessReviewLike(ResourceAttributesAccessReview item) {
    return new AccessReviewNested(item);
  }
  
  public AccessReviewNested<A> editAccessReview() {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(null));
  }
  
  public AccessReviewNested<A> editOrNewAccessReview() {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(new ResourceAttributesAccessReviewBuilder().build()));
  }
  
  public AccessReviewNested<A> editOrNewAccessReviewLike(ResourceAttributesAccessReview item) {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(item));
  }
  
  public String getState() {
    return this.state;
  }
  
  public A withState(String state) {
    this.state = state;
    return (A) this;
  }
  
  public boolean hasState() {
    return this.state != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PerspectiveVisibilityFluent that = (PerspectiveVisibilityFluent) o;
    if (!java.util.Objects.equals(accessReview, that.accessReview)) return false;
    if (!java.util.Objects.equals(state, that.state)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(accessReview,  state,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessReview != null) { sb.append("accessReview:"); sb.append(accessReview + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AccessReviewNested<N> extends ResourceAttributesAccessReviewFluent<AccessReviewNested<N>> implements Nested<N>{
    AccessReviewNested(ResourceAttributesAccessReview item) {
      this.builder = new ResourceAttributesAccessReviewBuilder(this, item);
    }
    ResourceAttributesAccessReviewBuilder builder;
    
    public N and() {
      return (N) PerspectiveVisibilityFluent.this.withAccessReview(builder.build());
    }
    
    public N endAccessReview() {
      return and();
    }
    
  
  }

}

==> openshift-model-operator-7.4.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/PerspectiveVisibilityFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PerspectiveVisibilityFluent<A extends PerspectiveVisibilityFluent<A>> extends BaseFluent<A>{
  public PerspectiveVisibilityFluent() {
  }
  
  public PerspectiveVisibilityFluent(PerspectiveVisibility instance) {
    this.copyInstance(instance);
  }
  private ResourceAttributesAccessReviewBuilder accessReview;
  private String state;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PerspectiveVisibility instance) {
    instance = (instance != null ? instance : new PerspectiveVisibility());
    if (instance != null) {
          this.withAccessReview(instance.getAccessReview());
          this.withState(instance.getState());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ResourceAttributesAccessReview buildAccessReview() {
    return this.accessReview != null ? this.accessReview.build() : null;
  }
  
  public A withAccessReview(ResourceAttributesAccessReview accessReview) {
    this._visitables.remove("accessReview");
    if (accessReview != null) {
        this.accessReview = new ResourceAttributesAccessReviewBuilder(accessReview);
        this._visitables.get("accessReview").add(this.accessReview);
    } else {
        this.accessReview = null;
        this._visitables.get("accessReview").remove(this.accessReview);
    }
    return (A) this;
  }
  
  public boolean hasAccessReview() {
    return this.accessReview != null;
  }
  
  public AccessReviewNested<A> withNewAccessReview() {
    return new AccessReviewNested(null);
  }
  
  public AccessReviewNested<A> withNewAccessReviewLike(ResourceAttributesAccessReview item) {
    return new AccessReviewNested(item);
  }
  
  public AccessReviewNested<A> editAccessReview() {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(null));
  }
  
  public AccessReviewNested<A> editOrNewAccessReview() {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(new ResourceAttributesAccessReviewBuilder().build()));
  }
  
  public AccessReviewNested<A> editOrNewAccessReviewLike(ResourceAttributesAccessReview item) {
    return withNewAccessReviewLike(java.util.Optional.ofNullable(buildAccessReview()).orElse(item));
  }
  
  public String getState() {
    return this.state;
  }
  
  public A withState(String state) {
    this.state = state;
    return (A) this;
  }
  
  public boolean hasState() {
    return this.state != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PerspectiveVisibilityFluent that = (PerspectiveVisibilityFluent) o;
    if (!java.util.Objects.equals(accessReview, that.accessReview)) return false;
    if (!java.util.Objects.equals(state, that.state)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(accessReview,  state,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessReview != null) { sb.append("accessReview:"); sb.append(accessReview + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AccessReviewNested<N> extends ResourceAttributesAccessReviewFluent<AccessReviewNested<N>> implements Nested<N>{
    AccessReviewNested(ResourceAttributesAccessReview item) {
      this.builder = new ResourceAttributesAccessReviewBuilder(this, item);
    }
    ResourceAttributesAccessReviewBuilder builder;
    
    public N and() {
      return (N) PerspectiveVisibilityFluent.this.withAccessReview(builder.build());
    }
    
    public N endAccessReview() {
      return and();
    }
    
  
  }

}
